# win32material
Apply some window effects to the Win32 Applications
![image](https://github.com/littlewhitecloud/win32material/assets/71159641/ffcea60c-718a-4315-9069-c1e4abc3f4cd)
![image](https://github.com/littlewhitecloud/win32material/assets/71159641/c9e522c5-d8c5-4563-a0e5-7fef39366a1d)
![image](https://github.com/littlewhitecloud/win32material/assets/71159641/787b8dec-3850-47ac-8c21-3441a4976b65)
![image](https://github.com/littlewhitecloud/win32material/assets/71159641/dd3f26d6-fa07-44be-9f7a-245d371cda5f)
